@@ -48,17 +48,20 @@ mkdir -p $measdir_full
 dstr=$(date +"%Y-%m-%dT%H%M%S")
 ofname=$measdir/measurement-${dstr}.csv
 ofnames=$measdir/measurement-${dstr}-slow.csv
+ofnamee=$measdir/measurement-${dstr}-events.csv
 
 ofname_full=$XC_WORKDIR/$ofname
 ofnames_full=$XC_WORKDIR/$ofnames
 
 echo "PWD: $PWD"
+echo "CMD: $umprog -c $XC_WORKDIR/etc/sensorsettings.ini --outfile=$ofname --downsample-outfile=$ofnames"
 
-$umprog -c $XC_WORKDIR/etc/sensorsettings.ini --outfile=$ofname --downsample-outfile=$ofnames >> $logfile 2>&1 &
+$umprog -c $XC_WORKDIR/etc/sensorsettings.ini --outfile=$ofname --downsample-outfile=$ofnames --events-outfile=$ofnamee >> $logfile 2>&1 &
 rpid=$!
 
 ln -sfT measurement-${dstr}.csv $measdir/latest.csv
 ln -sfT measurement-${dstr}-slow.csv $measdir/latest-slow.csv
+ln -sfT measurement-${dstr}-events.csv $measdir/latest-events.csv
 
 echo "Start measurement process $rpid"
 
