@@ -37,6 +37,11 @@ if ! grep disable-logging /etc/uwsgi-emperor/vassals/xc_uwsgi.ini; then
     echo "disable-logging = true" >> /etc/uwsgi-emperor/vassals/xc_uwsgi.ini
 fi
 
+cd $XC_WORKDIR
+if ! [[ -f upgrade.log ]]; then echo "" > upgrade.log; fi
+if ! [[ -f update.log ]]; then echo "" > update.log; fi
+if ! [[ -f measurement.log ]]; then echo "" > measurement.log; fi
+
 runUser=www-data
 ruuid=$(id -u $runUser)
 
