@@ -46,51 +46,59 @@ meas.error = function(text, timeout) {
 meas.updateControls = function(dummy) {
     var x = document.forms['displayRange']
     if (x != undefined) {
-	var rs = Number(x.start.value)
-	var bs = Number(x.blocksz.value)
-	if (bs < 1) {
-	    bs = 1
-	}
-	if (bs > meas.n) {
-	    bs = meas.n
-	}
-	var re = rs + bs
-	if (re > meas.n+1) {
-	    re = meas.n+1
-	}
-	if (rs + bs > meas.n+1) {
-	    rs = meas.n+1 - bs
-	}
-	if (rs < 1) {
-	    rs = 1
-	}
-	meas.range = [rs, re]
+	meas.range = meas.updateRange(x)
     }
     meas.doUpdateControls()
 }
 
+meas.updateRange = function(x) {
+    var rs = Number(x.start.value)
+    var bs = Number(x.blocksz.value)
+    if (bs < 1) {
+	bs = 1
+    }
+    if (bs > meas.n) {
+	bs = meas.n
+    }
+    var re = rs + bs
+    if (re > meas.n+1) {
+	re = meas.n+1
+    }
+    if (rs + bs > meas.n+1) {
+	rs = meas.n+1 - bs
+    }
+    if (rs < 1) {
+	rs = 1
+    }
+    return [rs, re]
+}
+
 meas.doUpdateControls1 = function() {
     var dispSelectButtons = ''
     var pinds = meas.headerInfo.pi.slice(1)
     var plainItemNames = pinds.map((k) => meas.headerInfo.names[k])
     var dispItemNames = plainItemNames.map((k) => meas.translateMeasName(k).replace('_', ' '))
     var grtempcols = 'auto'
-    dispSelectButtons += '<button onclick="meas.loadDiagramNew(\'' + plainItemNames.join(',') + '\')"><span>'
+	var class_1 = plainItemNames.join(',') == meas.mode ? 'xc-active-link' : ''
+    dispSelectButtons += '<button class="' + class_1 + '" onclick="meas.loadDiagramNew(\'' + plainItemNames.join(',') + '\')"><span>'
 	+ dispItemNames.join('</span> / <span>') + '</span></button>'
 
     Object.keys(meas.headerInfo.c3).forEach((k) => {
 	var item = meas.headerInfo.c3[k]
 	var cinds = item.inds
 	var itemNames = cinds.map((k) => meas.headerInfo.names[k])
-	dispSelectButtons += '<button onclick="meas.loadDiagramNew(\'' + itemNames.join(',') + '\')"><span class="tlt">' + k + '</span> (3D)</button>'
+
+
+	var class_2 = itemNames.join(',') == meas.mode ? 'xc-active-link' : ''
+	dispSelectButtons += '<button class="' + class_2 + '" onclick="meas.loadDiagramNew(\'' + itemNames.join(',') + '\')"><span class="tlt">' + k + '</span> (3D)</button>'
 	grtempcols += ' auto'
     })
-
-    dispSelectButtons += '<button onclick="meas.loadTable()" class="tlt">Measurement as table</button>'
+	var class_3 = 'table' == meas.mode ? 'xc-active-link' : ''
+    dispSelectButtons += '<button class="' + class_3 + ' tlt" onclick="meas.loadTable()">Measurements as table</button>'
     grtempcols += ' auto'
 
     xc.inject('result-dispsels',
-	      '<div style="display: grid; grid-template-columns: ' + grtempcols + '; grid-gap: 1em;">' + dispSelectButtons + '</div>'
+	      '<div class="settingssubmenu" style="grid-template-columns: ' + grtempcols + ';">' + dispSelectButtons + '</div>'
 	     )
 }
 
@@ -336,10 +344,30 @@ meas.inttype = function(k) {
     else if (k == 4) return 'alarm-high'
 }
 
+meas.normAccel = 9.80665
+
+meas.getUnit = function(name, headerInfo) {
+    if (headerInfo == undefined) {
+	headerInfo = meas.headerInfo
+    }
+    var vi = headerInfo.names.indexOf(name)
+    var unit = headerInfo.units[vi]
+    if (unit)
+	unit = unit.substring(1, unit.length-1)
+    return unit
+}
+
 meas.setBorders = function(data) {
     meas.borders = data
     for (b in meas.borders) {
 	var ent = meas.borders[b]
+	var unit = meas.getUnit(b)
+	if (unit == '(m/s²)') {
+	    ent.min *= meas.normAccel
+	    ent.wmin *= meas.normAccel
+	    ent.wmax *= meas.normAccel
+	    ent.max *= meas.normAccel
+	}
 	ent.intervals = []
 	ent.intervals.push([-Infinity, ent.min])
 	ent.intervals.push([ent.min, ent.wmin])
@@ -642,46 +670,145 @@ meas.loadTable = function() {
     meas.mode = 'table'
 };
 
+meas.initSettings = function(x, ev) {
+    var form = x.document.querySelector('form.xc-action')
+    form['sample-rate'].onchange()
+    // form['full-precision'].onchange()
+    form['accel-filter-bandwidth'].onchange()
+    form['gyro-filter-bandwidth'].onchange()
+
+    var dFields = ['effsrate', 'datarate', 'accel-filter-eff-bandwidth', 'gyro-filter-eff-bandwidth']
+    for (i in dFields) {
+	var key = dFields[i]
+	form[key].setAttribute('value', form[key].value)
+    }
+}
+
 meas.onChangeSettings = function(x, ev) {
     console.log('onchange settings', x.id)
     var form = x.form
-    if (x.id == 'settings-sample-rate') {
-	if (x.selectedIndex == 0) {
-	    form['accel-filter'].checked = false
-	    form['gyro-filter'].checked = false
-	} else {
-	    form['accel-filter'].checked = true
-	    form['gyro-filter'].checked = true
+    var updateEffsRate = ()=> {
+	var pktType = 1
+	if (form['accel'].checked && form['gyro'].checked && form['full-precision'].checked) {
+	    pktType = 4
+	} else if (form['accel'].checked && form['gyro'].checked) {
+	    pktType = 3
+	} else if (form['gyro'].checked) {
+	    pktType = 2
+	} else if (form['accel'].checked) {
+	    pktType = 1
 	}
-	form['accel-filter'].onchange()
-	form['gyro-filter'].onchange()
-    } else if (x.id == 'accel-filter') {
-	var g = form['gyro-filter']
-	if (x.checked || g.checked) {
-	    if (form['settings-sample-rate'].selectedIndex == 0) {
-		form['settings-sample-rate'].selectedIndex = 1
-	    }
-	} else {
-	    if (form['settings-sample-rate'].selectedIndex != 0) {
-		form['settings-sample-rate'].selectedIndex = 0
-		form['settings-sample-rate'].onchange()
-	    }
+	var pktBytes = 8
+	if (pktType == 3) {
+	    pktBytes = 16
+	} else if (pktType == 4) {
+	    pktBytes = 20
 	}
-	form['accel-bandwidth'].disabled = !x.checked
-    } else if (x.id == 'gyro-filter') {
-	var a = form['accel-filter']
-	if (x.checked || a.checked) {
-	    if (form['settings-sample-rate'].selectedIndex == 0) {
-		form['settings-sample-rate'].selectedIndex = 1
-		form['settings-sample-rate'].onchange()
-	    }
+	var effSR = Number(form['sample-rate'].value) / Number(form['packet-decimation'].value)
+	form['effsrate'].value = effSR
+	var drate = effSR * pktBytes / 1000
+	form['datarate'].value = drate
+	if (drate > 160) {
+	    form['datarate'].style.background = '#80000030'
+	    form['datarate'].style.border     = '0.1em solid red'
 	} else {
-	    if (form['settings-sample-rate'].selectedIndex != 0) {
-		form['settings-sample-rate'].selectedIndex = 0
-		form['settings-sample-rate'].onchange()
-	    }
+	    form['datarate'].style.removeProperty('background')
+	    form['datarate'].style.removeProperty('border')
 	}
-	form['gyro-bandwidth'].disabled = !x.checked
+    }
+    if (x.id == 'sample-rate') {
+	updateEffsRate()
+	form['accel-filter-bandwidth'].onchange()
+	form['gyro-filter-bandwidth'].onchange()
+
+    } else if (x.id == 'packet-decimation') {
+	updateEffsRate()
+
+    } else if (x.id == 'accel') {
+	var sr = form['sample-rate']
+	if (!x.checked) {
+	    if (!form['gyro'].checked) {
+		form['gyro'].checked = true
+	    }
+	    form['full-precision'].checked = false
+	    form['full-precision'].onchange()
+	}
+	updateEffsRate()
+
+    } else if (x.id == 'gyro') {
+	var sr = form['sample-rate']
+	if (!x.checked) {
+	    if (!form['accel'].checked) {
+		form['accel'].checked = true
+	    }
+	    form['full-precision'].checked = false
+	    form['full-precision'].onchange()
+	}
+	updateEffsRate()
+
+    } else if (x.id == 'full-precision') {
+	if (x.checked) {
+	    form['gyro-resolution'].selectedIndex = 1
+	    form['gyro-range'].selectedIndex = 0
+	    form['gyro-range'].disabled = true
+
+	    form['accel-resolution'].selectedIndex = 1
+	    form['accel-range'].selectedIndex = 0
+	    form['accel-range'].disabled = true
+
+	    form['gyro'].checked = true
+	    form['accel'].checked = true
+	    form['accel'].onchange()
+	} else {
+	    form['gyro-resolution'].selectedIndex = 0
+	    form['gyro-range'].disabled = false
+	    form['accel-resolution'].selectedIndex = 0
+	    form['accel-range'].disabled = false
+	}
+	updateEffsRate()
+
+    } else if (x.id == 'accel-aa-filter-enable') {
+	form['accel-aa-filter-bandwidth'].disabled = !x.checked
+    } else if (x.id == 'gyro-aa-filter-enable') {
+	form['gyro-aa-filter-bandwidth'].disabled = !x.checked
+    } else if (x.id == 'gyro-notch-filter-enable') {
+	form['gyro-notch-filter-bandwidth'].disabled = !x.checked
+	form['gyro-notch-filter-center-X'].disabled = !x.checked
+	form['gyro-notch-filter-center-Y'].disabled = !x.checked
+	form['gyro-notch-filter-center-Z'].disabled = !x.checked
+
+    } else if (x.id == 'gyro-filter-low-latency') {
+	var bw = form['gyro-filter-bandwidth']
+	if (bw.selectedIndex > 1) {
+	    bw.selectedIndex = 1
+	}
+	bw.onchange()
+    } else if (x.id == 'gyro-filter-bandwidth') {
+	if (x.selectedIndex > 1) {
+	    form['gyro-filter-low-latency'].checked = false
+	}
+	var sr = Number(form['sample-rate'].value)
+	var divi = Number(x.value.split('/')[1])
+	var effBW = (sr / divi) / 2
+	form['gyro-filter-eff-bandwidth'].value = effBW
+
+    } else if (x.id == 'accel-filter-low-latency') {
+	var bw = form['accel-filter-bandwidth']
+	if (bw.selectedIndex > 1) {
+	    bw.selectedIndex = 1
+	}
+	bw.onchange()
+    } else if (x.id == 'accel-filter-bandwidth') {
+	if (x.selectedIndex > 1) {
+	    form['accel-filter-low-latency'].checked = false
+	}
+	var sr = Number(form['sample-rate'].value)
+	var divi = Number(x.value.split('/')[1])
+	var effBW = (sr / divi) / 2
+	form['accel-filter-eff-bandwidth'].value = effBW
+
+    } else if (x.id == 'temp0') {
+	x.checked = true
     }
 }
 
@@ -865,6 +992,7 @@ meas.processHeadline = function(text) {
     meas.headline = text
     meas.headers = meas.parseMeasurementHeaders(text)
     meas.headerInfo = meas.partitionMeasurementHeaders(meas.headers)
+    meas.borders = undefined
 }
 
 meas.psMeasurementHeaders = function(text) {
@@ -910,7 +1038,7 @@ meas.psLatestMeasurements = function(text) {
     if (meas.borders == undefined) {
 	meas.loadBorders(function() {
 	})
-	return ''
+	return {noupdate: true}
     }
 
     var items = text.split(';')
@@ -1029,19 +1157,15 @@ meas.psLatestMeasurements = function(text) {
 	}
 
 	gridcols = []
-	var kv = 1, ks = 1
+	var kv = 1, ks = 0
 	// skip time
 	gridcols.push(0)
 	for (var i = 1; i < values.length; ++i) {
 	    if (meas.headerInfo.pi.indexOf(i) > -1) {
 		if (meas.headerInfo.pi.indexOf(i) == meas.headerInfo.pi.length -1) {
-		    if (ks%3 == 0) {
-			gridcols.push('' + (ks%3) + '/4')
-		    } else {
-			gridcols.push(ks%3)
-		    }
+		    gridcols.push('' + (ks%3 + 1) + '/4')
 		} else {
-		    gridcols.push((ks%3))
+		    gridcols.push((ks%3) + 1)
 		}
 		ks += 1
 	    } else {
@@ -1080,19 +1204,19 @@ meas.psLatestMeasurements = function(text) {
 	var nitem = values[k]
 	var range = ranges[k]
 	var s = '<div>'
-	if (nitem.mind != 0 || nitem.maxd != 0) {
+	if (nitem.mind != 0 || nitem.maxd != 0 || true) {
 	    s = '<div class="value-range">' +
-		'<div class="min-value">' + item.mind + '</div>' +
+		'<div class="min-value">' + (nitem.mind ? item.mind : '') + '</div>' +
 		' <div class="mean-value">' + item.mean + '</div> ' +
-		'<div class="max-value">' + item.maxd + '</div>' +
+		'<div class="max-value">' + (nitem.maxd ? item.maxd : '') + '</div>' +
 		'</div>'
-	    if (range > 0) {
-		var wperc = (100 * nitem.range / range), wcol = 'grey'
+	    if (range > 0 || true) {
+		var wperc = range > 0 ? (100 * nitem.range / range) : 0, wcol = 'grey'
 		if (wperc > 100) {
 		    wperc = 100
 		    wcol = 'red'
 		}
-		s += '<div class="mv-bar" style="width: ' + wperc + '%; background: ' + wcol + '">&nbsp;</div>'
+		s += '<div data-perc="' + wperc + '" data-nrange="' + nitem.range + '" data-range="' + range + '" class="mv-bar" style="width: ' + wperc + '%; background: ' + wcol + '">&nbsp;</div>'
 	    }
 	} else {
 	    s = '<div class="value">' + item.mean + '</div>'
@@ -1100,6 +1224,7 @@ meas.psLatestMeasurements = function(text) {
 	return s
     })
     tds[0] = '<div><span class="value">' +  formattedValues[0] + '</span></div>'
+    var sepDone = 0
     Object.keys(tds).forEach((i) => {
 	i = Number(i)
 	var head = headers[i]
@@ -1131,9 +1256,10 @@ meas.psLatestMeasurements = function(text) {
 	    tds[i] = html
 	} else {
 	    var html = ''
-	    if (mode != 'aggr' && i > 0) {
+	    if (mode != 'aggr' && i > 0 && sepDone == 0) {
 		html += '<div style="grid-column: 1/4;" class="livevalue-header"><span class="lv-head">' +
 		    tl.transl('Single values') + '</span></div>'
+		sepDone = 1
 	    }
 	    html += '<div title="' + title + '" style="grid-column: ' + col + ';" class="livevalue ' + classes[i] + '">' +
 		'<span class="lv-head">' + head + '</span><br/><div class="lv-value">' + tds[i] + '</div></div>'
@@ -1276,6 +1402,11 @@ meas.onchangeLimitHead = function(target, event) {
 	    target.form.elements.wmin.value = defBorders.wmin
 	    target.form.elements.wmax.value = defBorders.wmax
 	    target.form.elements.max.value = defBorders.max
+	    target.form.elements.max.dataset.tdone = 0
+	    target.form.elements.min.dataset.tdone = 0
+	    target.form.elements.wmax.dataset.tdone = 0
+	    target.form.elements.wmin.dataset.tdone = 0
+	    tl.update(target.form)
 	} else {
 	    target.form.elements.min.value = ''
 	    target.form.elements.wmin.value = ''
@@ -1289,13 +1420,18 @@ meas.psLimitSelector = function(data, el) {
     meas.processHeadline(data)
 
     var text = ''
-
+    var getunit = (val)=> {
+	val = val.split('_')[0]
+	if (val == 'Acceleration') return 'g'
+	else if (val == 'Rotation') return '°/s'
+	else if (val == 'Temperature') return '°C'
+    }
     text += '<label for="limit-head" class="tlt">Value</label>'
     text += '<select id="limit-head" name="head" onchange="meas.onchangeLimitHead(this, event)">'
     var opts = Object.keys(meas.headerInfo.names).map((k) => {
 	var name = meas.headerInfo.names[k]
 	var unit = meas.headerInfo.units[k]
-	return '<option value="' + name + '">' + meas.translateMeasName(name).replace('_', ' ') + '</option>'
+	return '<option value="' + name + '">' + meas.translateMeasName(name).replace('_', ' ') + ' (' + getunit(name) + ')</option>'
     })
     text += opts.slice(1).join('')
     text += '</select>'
@@ -1396,7 +1532,7 @@ tl.apptable({
     logf: {de: 'Logdatei', en: 'Log file'},
 
     mlv: {de: 'Messwerte Live-Anzeige', en: 'Measurement Live View'},
-    mat: {de: 'Messwerte als Tabelle', en: 'Measurement as table'},
+    mat: {de: 'Messwerte als Tabelle', en: 'Measurements as table'},
 
     mpc: {de: 'Messprozesssteuerung', en: 'Measurement Process Control'},
     cmd: {de: 'Befehlszeile', en: 'Command line'},
@@ -1479,6 +1615,7 @@ tl.apptable({
     sts1: {de: 'Gerätestatus', en: 'Device status'},
     sts2: {de: 'WiFi-Status', en: 'WiFi status'},
     sts3: {de: 'Festplattenstatus', en: 'Disk status'},
+    sts4: {de: 'Netzwerkstatus', en: 'Network status'},
 
     scolh1: {de: 'Name', en: 'Name'},
     scolh2: {de: 'Datum', en: 'Date'},
@@ -1506,9 +1643,43 @@ tl.apptable({
     stn2: {de: 'Messbereich', en: 'Measurement range'},
     stn3: {de: 'Einheit', en: 'Unit'},
     stn4: {de: 'Filter', en: 'Filter'},
-    stn5: {de: 'Tiefpass-Filter', en: 'Low Pass Filter'},
+    stn5: {de: 'Tiefpass-Filter', en: 'Low-pass filter'},
     stn6: {de: 'Bandbreite', en: 'Band width'},
     stn7: {de: 'Einzelwerte', en: 'Single values'},
+    stn8: {de: 'Bandsperre', en: 'Notch filter'},
+    stn9: {de: 'Antialiasing', en: 'Anti-aliasing'},
+    stn10: {de: 'Antialiasing-Filter', en: 'Anti-aliasing filter'},
+    stn11: {de: 'Versatz', en: 'Offset'},
+    stn12: {de: 'Mittenfrequenz', en: 'Center frequency'},
+    stn13: {de: 'Aktivieren', en: 'Enable'},
+    stn14: {de: 'Ordnung', en: 'Order'},
+    stn15: {de: 'Niedrige Latenz', en: 'Low latency'},
+    stn16: {de: 'Volle Auflösung', en: 'Full precision'},
+    stn17: {de: 'Auflösung', en: 'Resolution'},
+    stn18: {de: 'X', en: 'X'},
+    stn19: {de: 'Y', en: 'Y'},
+    stn20: {de: 'Z', en: 'Z'},
+    stn21: {de: 'Eff. Messfrequenz', en: 'Eff. sample rate'},
+    stn22: {de: 'Datenrate', en: 'Data rate'},
+    stn23: {de: 'Werten', en: 'values'},
+    stn24: {de: 'Ausgabe: 1 von', en: 'Output 1 of'},
+    stn25: {de: 'Eff. Bandbreite', en: 'Eff. bandwidth'},
+    stn26: {de: 'Holen', en: 'Fetch'},
+    stn27: {de: 'Frei lassen für Werkseinstellungen, oder', en: 'Leave blank to use factory trimmed parameters, or'},
+    stn28: {de: 'vom Sensor', en: 'from sensor'},
+    stn29: {de: 'Erweitert', en: 'Advanced'},
+    stn30: {de: 'Ereignis beended', en: 'event ended'},
+    stn31: {de: 'Schließen', en: 'Close'},
+    stn32: {de: 'Aktualisieren', en: 'Reload'},
+
+    osr1:  {de: 'Messfrequenz/2',  en: 'Sample rate/2'},
+    osr2:  {de: 'Messfrequenz/4',  en: 'Sample rate/4'},
+    osr3:  {de: 'Messfrequenz/5',  en: 'Sample rate/5'},
+    osr4:  {de: 'Messfrequenz/8',  en: 'Sample rate/8'},
+    osr5:  {de: 'Messfrequenz/10', en: 'Sample rate/10'},
+    osr6:  {de: 'Messfrequenz/16', en: 'Sample rate/16'},
+    osr7:  {de: 'Messfrequenz/20', en: 'Sample rate/20'},
+    osr8:  {de: 'Messfrequenz/40', en: 'Sample rate/40'},
 
     btn1: {de: 'Speichern', en: 'Save'},
 })
@@ -1536,3 +1707,101 @@ meas.showCSV = function(text) {
 
     return table
 }
+
+meas.psEventList = function(text) {
+    if (text.length == 0) {
+	return '<span class="tlt">no events</span>'
+    }
+
+    var classes = [ 'alarm-low', 'warn-low', 'ok-low', 'warn-high', 'alarm-high' ]
+    var tmap = (t)=> {
+	return classes[t+2]
+    }
+
+    var items = text.split('\n')
+    items = items.slice(0, -1)
+
+    var elems = items.map((x)=> x.split(';')).reverse()
+
+//    var eHeader = elems[0]
+//    elems = elems.slice(1)
+
+    var prows = elems.map((fields)=> {
+	fields[1] = JSON.parse(fields[1])
+	return fields
+    })
+
+//    var prows = prows.filter((fields)=> fields[1].length > 0)
+
+    var rows = prows.map((fields)=> {
+	var ts = new Date(fields[0]*1000).toLocaleString()
+	var evData = fields[1]
+	var evclass = 'event'
+	var res = ''
+	if (evData.length>0) {
+	    for (var i = 0; i < evData.length; ++i) {
+		var s = ''
+		if (i == 0) {
+		    s += '<td class="ts">' + ts + '</td>'
+		} else {
+		    s += '<td/>'
+		}
+		var unit = meas.getUnit(evData[i].source, meas.events.headerInfo)
+		s += '<td>' + meas.translateMeasName(evData[i].source).replace('_', ' ') + '</td>'
+		s += '<td class="' + tmap(evData[i].type) + '">' + evData[i].value + ' ' + unit + '</td>'
+		//	s += '<td class="' + tmap(evData.type) + '">&nbsp;</td>'
+		res += '<tr class="event">' + s + '</tr>'
+	    }
+	} else {
+	    var s = '<td class="ts">' + ts + '</td>'
+	    s += '<td class="tlt">event ended</td><td></td>'
+	    res = '<tr class="noevent">' + s + '</tr>'
+	}
+	return res
+    })
+
+    var tbl = '<table>' + rows.join('\n') + '</table>'
+    var html = '<div class="events">'
+    html += '<a class="xc-nocatch floatr tlt" href="#" onclick="meas.updateEventsList(event)">Reload</a> '
+    html += '<a class="xc-nocatch floatr tlt" href="#" onclick="meas.closeDynamicSection(event)">Close</a>'
+    html += tbl
+    html += '</div>'
+    return html
+}
+
+meas.events = { range: [0, 4000], fname: '' }
+
+meas.inject = function(id, html, ev, done) {
+    var target = document.querySelector('#' + id)
+    xc.inject(id, html)
+    updateTreeFinal(target, ev, function(a,b) {
+	done(a, b)
+    })
+}
+
+meas.updateEventsList = function(ev) {
+    var fname = meas.events.fname
+    xlp.sendGet('/main/range?path=' + fname + '&start=' + meas.events.range[0] + '&end=' + meas.events.range[1], function(s, resp) {
+	if (s != 0) { return }
+	xlp.sendGet('/main/head?path=' + meas.events.measname + '&n=1', function(s, respH) {
+	    if (s != 0) { return }
+	    meas.events.headers = meas.parseMeasurementHeaders(respH.responseText)
+	    meas.events.headerInfo = meas.partitionMeasurementHeaders(meas.events.headers)
+
+	    var html = meas.psEventList(resp.responseText)
+	    meas.inject('event-view', html, ev, function(a,b) {
+		console.log('Events list updated')
+	    })
+	})
+    })
+}
+
+meas.loadEvents = function(fname, ev) {
+    meas.events.fname = fname
+    meas.events.measname = fname.split('-events').join('')
+    meas.updateEventsList(ev)
+}
+
+meas.closeDynamicSection = function(event) {
+    event.target.parentElement.innerHTML = ''
+}
